<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>SnapIntersection</name>
    <message>
        <location filename="../SnapIntersectionInit.js" line="+2"/>
        <source>&amp;Intersection</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
P&amp;rzecięcie</translatorcomment>
        <translation>P&amp;rzecięcie</translation>
    </message>
</context>
</TS>
